package com.adc.da.report.controller;

import com.adc.da.mp.base.BaseController;
import com.adc.da.mp.base.IBaseService;
import com.adc.da.mp.base.Query;
import com.adc.da.report.entity.AnalysisReportEO;
import com.adc.da.report.service.IAnalysisReportEOService;
import com.adc.da.report.service.IRetUsersEOService;
import com.adc.da.util.http.PageInfo;
import com.adc.da.util.http.ResponseMessage;
import com.adc.da.util.http.Result;
import com.adc.da.util.utils.StringUtils;
import com.adc.da.util.utils.UserUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import static org.springframework.http.MediaType.APPLICATION_JSON_VALUE;

/**
 * <p>
 * 前端控制器
 * </p>
 * 作者 gen
 * 日期 2021-09-16
 */
@RestController
@RequestMapping("/${restPath}/report/analysisReport")
@Api(tags = "|AnalysisReportEO|报告分析")
public class AnalysisReportEOController extends BaseController<AnalysisReportEO> {
    private static final Logger logger = LoggerFactory.getLogger(AnalysisReportEOController.class);

    @Autowired
    private IAnalysisReportEOService service;

    @Autowired
    private IRetUsersEOService retUsersEOService;

    @ApiOperation(value = "|AnalysisReportEO|列表查询", notes = "report:analysisreport:list")
    @PostMapping(value = "list", consumes = APPLICATION_JSON_VALUE)
    //@RequiresPermissions("report:analysisreport:list")
    public ResponseMessage<List<AnalysisReportEO>> getList(@RequestBody Query<AnalysisReportEO> query) {

        return Result.success(super.list(query));
    }

    @ApiOperation(value = "|AnalysisReportEO|分页查询", notes = "report:analysisreport:page")
    @PostMapping(value = "page", consumes = APPLICATION_JSON_VALUE)
    //@RequiresPermissions("report:analysisreport:page")
    public ResponseMessage<PageInfo<AnalysisReportEO>> getPage(@RequestBody Query<AnalysisReportEO> query) {
        String permission = UserUtil.getReportPermission();//获取所有报告权限
        String qyid = UserUtil.getQyId();

        PageInfo<AnalysisReportEO> pageInfo = getPageInfo(super.page(query));
        if ("1".equals(permission)) {//拥有全部报告查看权限
            for (AnalysisReportEO analysisReportEO : pageInfo.getList()) {
                analysisReportEO.setPermission("1");
            }
        } else {
            for (AnalysisReportEO analysisReportEO : pageInfo.getList()) {
                if (StringUtils.isNotBlank(analysisReportEO.getBugUsers()) && analysisReportEO.getBugUsers().contains(qyid)) {
                    //单个报告购买
                    analysisReportEO.setPermission("1");
                } else {
                    analysisReportEO.setPdfFile(analysisReportEO.getCoverFile());
                }
            }
        }
        return Result.success(pageInfo);
    }

    @ApiOperation(value = "|AnalysisReportEO|获取所有企业", notes = "report:analysisreport:getAllUsers")
    @GetMapping("/getAllUsers")
    //@RequiresPermissions("report:analysisreport:get")
    public ResponseMessage<List<Map<String, Object>>> getAllUsers() {
        String qyid = UserUtil.getQyId();
        List<Map<String, Object>> list = new ArrayList<>();
        if ("adc".equals(qyid)) {
            list = retUsersEOService.getAllUsers();
        }
        return Result.success(list);
    }

    @ApiOperation(value = "|AnalysisReportEO|详情", notes = "report:analysisreport:get")
    @GetMapping("{id}")
    //@RequiresPermissions("report:analysisreport:get")
    public ResponseMessage<AnalysisReportEO> get(@NotNull @PathVariable Serializable id) {
        AnalysisReportEO analysisReportEO = super.getById(id);
        String permission = UserUtil.getReportPermission();//获取所有报告权限
        String qyid = UserUtil.getQyId();
        if ("1".equals(permission)) {//拥有全部报告查看权限
            analysisReportEO.setPermission("1");
        } else {
            if (StringUtils.isNotBlank(analysisReportEO.getBugUsers()) && analysisReportEO.getBugUsers().contains(qyid)) {
                //单个报告购买
                analysisReportEO.setPermission("1");
            } else {
                analysisReportEO.setPdfFile(analysisReportEO.getCoverFile());
            }
        }
        return Result.success(analysisReportEO);
    }

    @ApiOperation(value = "|AnalysisReportEO|新增", notes = "report:analysisreport:save")
    @PostMapping(consumes = APPLICATION_JSON_VALUE)
    //@RequiresPermissions("report:analysisreport:save")
    public ResponseMessage<AnalysisReportEO> create(@RequestBody AnalysisReportEO data) {
        String qyid = UserUtil.getQyId();
        data.setBugUsers(qyid);
        return Result.success(super.save(data));
    }

    @ApiOperation(value = "|AnalysisReportEO|修改", notes = "report:analysisreport:update")
    @PutMapping(consumes = APPLICATION_JSON_VALUE)
    //@RequiresPermissions("report:analysisreport:update")
    public ResponseMessage<AnalysisReportEO> modify(@RequestBody AnalysisReportEO data) {

        return Result.success(super.update(data));
    }

    @ApiOperation(value = "|AnalysisReportEO|批量删除", notes = "report:analysisreport:delete")
    @DeleteMapping("{ids}")
    //@RequiresPermissions("report:analysisreport:delete")
    public ResponseMessage delete(@NotNull @PathVariable Serializable... ids) {

        return Result.success(super.deleteBatchIds(ids));
    }

    @ApiOperation(value = "|AnalysisReportEO|分类统计", notes = "report:analysisreport:typeGroup")
    @GetMapping("/typeGroup")
    //@RequiresPermissions("report:analysisreport:update")
    public ResponseMessage<List<Map<String, Object>>> typeGroup() {

        return Result.success(service.typeGroup());
    }

    @Override
    protected IBaseService<AnalysisReportEO> getService() {

        return service;
    }

    @Override
    protected void verifyQuery(Query<AnalysisReportEO> queryItem) {

    }

    @Override
    protected void verifySaveData(AnalysisReportEO data) {

    }

    @Override
    protected void verifyUpdateData(AnalysisReportEO data) {

    }

    @Override
    protected void verifyDeleteId(Serializable... ids) {

    }
}
